==> kjy-taskcenter-api-0.0.18-sources.jar: cn/com/duiba/kjy/taskcenter/api/constants/TaskCenterRocketMqTag.java <==
package cn.com.duiba.kjy.taskcenter.api.constants;

/**
 * @author wangbinbin
 * @create 2020-10-28 10:02
 * @descript taskCenter生产者tag
 */
public class TaskCenterRocketMqTag {

    /**
     * 延时访问推送
     */
    public static final String TAG_NEW_VISIT_INFORMATION = "KJY_NEW_VISIT_INFORMATION";

    /**
     * 早报试推
     */
    public static final String DAILY_TRY_PUSH_TAG = "DAILY_TRY_PUSH_TAG";

    /**
     * 自定义推送 试推
     */
    public static final String CUSTOM_PUSH_TRY_PUSH_TAG = "CUSTOM_PUSH_TRY_PUSH_TAG";


    /**
     * 晚安心语推送 试推
     */
    public static final String EVENING_PUSH_TRY_PUSH_TAG = "EVENING_PUSH_TRY_PUSH_TAG";

    /**
     * 种草素材推送 试推
     */
    public static final String GRASS_CONTENT_PUSH_TRY_PUSH_TAG = "GRASS_CONTENT_PUSH_TRY_PUSH_TAG";

    /**
     * 热文素材推送 试推
     */
    public static final String HOT_CONTENT_PUSH_TRY_PUSH_TAG = "HOT_CONTENT_PUSH_TRY_PUSH_TAG";

    /**
     * 发圈素材推送 试推
     */
    public static final String TIMELINE_CONTENT_PUSH_TRY_PUSH_TAG = "TIMELINE_CONTENT_PUSH_TRY_PUSH_TAG";


    /**
     * 唤醒推送 试推
     */
    public static final String WAKEUP_PUSH_TRY_PUSH_TAG = "WAKEUP_PUSH_TRY_PUSH_TAG";

    /**
     * 直播推送 试推
     */
    public static final String LIVE_PUSH_TRY_PUSH_TAG = "LIVE_PUSH_TRY_PUSH_TAG";


    /**
     * 钉钉通知消息
     */
    public static final String TAG_KJJ_DING_TALK = "tag_kjj_ding_talk";

    /**
     * 优惠码到期提醒
     */
    public static final String PROMOTION_CODE_WILL_EXPIRE_REMIND = "PROMOTION_CODE_WILL_EXPIRE_REMIND";

    /**
     * 客服消息关闭预警客服消息推送
     */
    public static final String INTERACT_WILL_EXPIRE_REMIND_TAG = "INTERACT_WILL_EXPIRE_REMIND_TAG";


}

==> kjy-taskcenter-api-0.0.22-sources.jar: cn/com/duiba/kjy/taskcenter/api/constants/TaskCenterRocketMqTag.java <==
package cn.com.duiba.kjy.taskcenter.api.constants;

/**
 * @author wangbinbin
 * @create 2020-10-28 10:02
 * @descript taskCenter生产者tag
 */
public class TaskCenterRocketMqTag {

    /**
     * 延时访问推送
     */
    public static final String TAG_NEW_VISIT_INFORMATION = "KJY_NEW_VISIT_INFORMATION";

    /**
     * 早报试推
     */
    public static final String DAILY_TRY_PUSH_TAG = "DAILY_TRY_PUSH_TAG";

    /**
     * 自定义推送 试推
     */
    public static final String CUSTOM_PUSH_TRY_PUSH_TAG = "CUSTOM_PUSH_TRY_PUSH_TAG";


    /**
     * 晚安心语推送 试推
     */
    public static final String EVENING_PUSH_TRY_PUSH_TAG = "EVENING_PUSH_TRY_PUSH_TAG";

    /**
     * 种草素材推送 试推
     */
    public static final String GRASS_CONTENT_PUSH_TRY_PUSH_TAG = "GRASS_CONTENT_PUSH_TRY_PUSH_TAG";

    /**
     * 热文素材推送 试推
     */
    public static final String HOT_CONTENT_PUSH_TRY_PUSH_TAG = "HOT_CONTENT_PUSH_TRY_PUSH_TAG";

    /**
     * 发圈素材推送 试推
     */
    public static final String TIMELINE_CONTENT_PUSH_TRY_PUSH_TAG = "TIMELINE_CONTENT_PUSH_TRY_PUSH_TAG";


    /**
     * 唤醒推送 试推
     */
    public static final String WAKEUP_PUSH_TRY_PUSH_TAG = "WAKEUP_PUSH_TRY_PUSH_TAG";

    /**
     * 直播推送 试推
     */
    public static final String LIVE_PUSH_TRY_PUSH_TAG = "LIVE_PUSH_TRY_PUSH_TAG";


    /**
     * 钉钉通知消息
     */
    public static final String TAG_KJJ_DING_TALK = "tag_kjj_ding_talk";

    /**
     * 客服消息关闭预警客服消息推送
     */
    public static final String INTERACT_WILL_EXPIRE_REMIND_TAG = "INTERACT_WILL_EXPIRE_REMIND_TAG";

    /**
     * 早报补推
     */
    public static final String DAILY_SUPPLEMENT_PUSH_TAG = "DAILY_SUPPLEMENT_PUSH_TAG";

    /**
     * 晚安心语补推
     */
    public static final String EVENING_SUPPLEMENT_PUSH_TAG = "EVENING_SUPPLEMENT_PUSH_TAG";

    /**
     * 种草素材补推
     */
    public static final String GRASS_CONTENT_SUPPLEMENT_PUSH_TAG = "GRASS_CONTENT_SUPPLEMENT_PUSH_TAG";

    /**
     * 热文补推
     */
    public static final String HOT_CONTENT_SUPPLEMENT_PUSH_TAG = "HOT_CONTENT_SUPPLEMENT_PUSH_TAG";

    /**
     * 直播手动访客消息推送
     */
    public static final String LIVE_OPERATE_VISITOR_PUSH = "LIVE_OPERATE_VISITOR_PUSH";
}
